@@ -3,7 +3,7 @@
 # Copyright (C) 2018-2021 Joelle Maslak <jmaslak@antelope.net>
 
 package Net::Netmask;
-$Net::Netmask::VERSION = '2.0000';
+$Net::Netmask::VERSION = '2.0002';
 use 5.006_001;
 
 # ABSTRACT: Understand and manipulate IP netmasks
@@ -156,12 +156,17 @@ sub new {
         $bits = 128;
     }
 
-    $ibase = ascii2int( ( $base || '::' ), $proto ) unless defined $ibase;
+    $ibase = ascii2int( ( $base || '::' ), $proto ) unless (defined $ibase or $error);
     unless ( defined($ibase) || defined($error) ) {
         $error = "could not parse $net";
         $error .= " $mask" if $mask;
     }
 
+    if ($error) {
+        $ibase = 0;
+        $bits  = 0;
+    }
+
     $ibase = i_getnet_addr( $ibase, $bits, $proto );
 
     return bless {
@@ -185,6 +190,10 @@ sub i_getnet_addr {
 }
 
 sub new2 {
+    goto &safe_new;
+}
+
+sub safe_new {
     local ($debug) = 0;
     my $net = new(@_);
     return if $error;
